@@ -2,5 +2,5 @@
 
 char const *macro_definition(Macro const *macro)
 {
-    return stack_tos(&macro->d_definition);
+    return stack_tos(&macro->d_definition)->u_charCp;
 }
