@@ -2,14 +2,15 @@
 
 void parser_process(register Parser *pp)
 {
-    register unsigned idx;
+    register size_t idx;
     char const *preload;
 
             /* put all files in reversed order on the lexer's filestack, so */
             /* they will be processed in their reversed order, i.e., in the */
             /* order they were specified on the cmd line                    */
 
-    if (message_show(MSG_DEBUG)) message("Number of args `%u'", args_nArgs());
+    if (message_show(MSG_DEBUG)) message("Number of args `%u'", 
+                                         (unsigned)args_nArgs());
 
     for (idx = args_nArgs(); idx--; )
     {
