@@ -55,11 +55,11 @@ int main(int argc, char **argv)
 {
     FILE    *input = NULL;
     char    *endlabel = 0;
-    char    *indent = "";
+    char    *indent = 0;
     char    *label = 0;
     char    *progName = strrchr(argv[0], '/');
     char    *verbendl = "\n";
-    char    *vindent = "";
+    char    *vindent = 0;
     int     endLabelFound = 0;
     int     labelFound = 0;
     int     verbOpened = 0;
@@ -174,6 +174,10 @@ int main(int argc, char **argv)
         free(line);
     }
 
+    fclose(input);                              /* to make cppcheck happy */
+    free(indent);
+    free(vindent);
+
     if (!labelFound)
     {
         fprintf(stderr, "%s: label section not found\n", progName);
